*********
Bipartite
*********

.. automodule:: networkx.algorithms.bipartite


Basic functions
---------------
.. automodule:: networkx.algorithms.bipartite.basic
.. autosummary::
   :toctree: generated/

   is_bipartite
   is_bipartite_node_set
   sets
   color
   density
   degrees
   biadjacency_matrix

Projections
-----------
.. automodule:: networkx.algorithms.bipartite.projection
.. autosummary::
   :toctree: generated/

   projected_graph
   weighted_projected_graph
   collaboration_weighted_projected_graph
   overlap_weighted_projected_graph
   generic_weighted_projected_graph


Spectral
--------
.. automodule:: networkx.algorithms.bipartite.spectral
.. autosummary::
   :toctree: generated/

   spectral_bipartivity


Clustering
----------
.. automodule:: networkx.algorithms.bipartite.cluster
.. autosummary::
   :toctree: generated/

   clustering
   average_clustering


Redundancy
----------
.. automodule:: networkx.algorithms.bipartite.redundancy
.. autosummary::
   :toctree: generated/

   node_redundancy


Centrality
----------
.. automodule:: networkx.algorithms.bipartite.centrality
.. autosummary::
   :toctree: generated/

   closeness_centrality
   degree_centrality
   betweenness_centrality



